@@ -1,11 +1,16 @@
 <?php
 
-/* Templates Plugin
- * by Ryan Rubley (ryan@morpheussoftware.net)
- * (c) 2003 (GNU GPL - see ../../COPYING)
- *
- * Actual plugin functions are here
- */
+/**
+  * SquirrelMail Templates Plugin
+  * Copyright (c) 2005 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * Copyright (c) 2003-2005 Ryan Rubley <ryan@morpheussoftware.net>
+  * Licensed under the GNU GPL. For full terms see the file COPYING.
+  *
+  * @package plugins
+  * @subpackage templates
+  *
+  */
+
 
 include_once(SM_PATH . 'plugins/templates/common.php');
 
@@ -34,12 +39,13 @@ function plugin_templates_compose_button_row() {
     $template_postblank = getPref($data_dir, $username, 'template_postblank');
 
 ?>
-    <script type="text/javascript"><!--
+    <script type="text/javascript" language="JavaScript">
+    <!--
         templatetext = new Array();
 <?php
     //this is really hairy looking, but I think it works :)
     $js_strtr = array("'"=>"\'", '"'=>'\"', '\\'=>'\\\\', "\r"=>'\r', "\n"=>'\n', "\t"=>'\t');
-    $html = '<select name="template">';
+    $html = '<br /><select name="template">';
     $num = 1;
     while( LoadTemplate( $description, $templatetext, $num ) ) {
 		echo "templatetext[$num] = '" . strtr( $templatetext, $js_strtr ) . "';\n";
@@ -49,7 +55,8 @@ function plugin_templates_compose_button_row() {
 ?>
         function template_add() {
             var t = templatetext[document.compose.template.value];
-			var b = document.compose.body.value, nl = b.indexOf('\r\n')<0?'\n':'\r\n';
+            var b = document.compose.body.value;
+            var nl = (b.indexOf('\r\n') < 0 ? '\n' : '\r\n');
 <?php if( $template_preblank ) {
             echo 't = nl + t;';
       }
@@ -80,7 +87,7 @@ function plugin_templates_compose_button_row() {
             }
       } else { 
             if ($html_insert) {
-                  echo 'var ss = b.lastIndexOf(nl+'-'+'- '+nl);'
+                  echo 'var ss = b.lastIndexOf(nl+\'-\'+\'- \'+nl);'
                      . 'if( ss <= 0 ) ss = 0;'
                      . 't = t.replace(/\r\n/g, "<br />");'
                      . 'nl = nl.replace(/\r\n/g, "<br />");'
@@ -99,13 +106,14 @@ function plugin_templates_compose_button_row() {
                   else if ($editor_style == 2)
                         echo 'editor.insertHTML(b.substring(0,ss) + nl + t + b.substring(ss))';
             } else {
-                  echo 'var ss = b.lastIndexOf(nl+'-'+'- '+nl);'
+                  echo 'var ss = b.lastIndexOf(nl+\'-\'+\'- \'+nl);'
                      . 'if( ss <= 0 ) ss = 0;'
                      . 'document.compose.body.value = b.substring(0,ss) + nl + t + b.substring(ss);';
             }
       } ?>
         }
-	//--></script>
+	//-->
+        </script>
 <?php
 
     $html .= "</select>\n" .
