@@ -1,11 +1,16 @@
 <?php
 
-/* Templates Plugin
- * by Ryan Rubley (ryan@morpheussoftware.net)
- * (c) 2003 (GNU GPL - see ../../COPYING)
- *
- * required plugin stubs
- */
+/**
+  * SquirrelMail Templates Plugin
+  * Copyright (c) 2005 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * Copyright (c) 2003-2005 Ryan Rubley <ryan@morpheussoftware.net>
+  * Licensed under the GNU GPL. For full terms see the file COPYING.
+  *
+  * @package plugins
+  * @subpackage templates
+  *
+  */
+
 
 function squirrelmail_plugin_init_templates () {
     global $squirrelmail_plugin_hooks;
@@ -21,7 +26,7 @@ if (!defined('SM_PATH'))
     define('SM_PATH', '../');
 
 function templates_version() {
-	return '1.1';
+	return '1.2-1.4.0';
 }
 
 function plugin_templates_compose_button_row_stub() {
